diff src/normal.c @ 34229:6be721794e1f v9.1.0060

patch 9.1.0060: Recorded register cannot be translated using keytrans() Commit: https://github.com/vim/vim/commit/bf321806bf44d59f108fd7e5a0eaead04682701d Author: zeertzjq <zeertzjq@outlook.com> Date: Sun Jan 28 19:03:00 2024 +0100 patch 9.1.0060: Recorded register cannot be translated using keytrans() Problem: Recorded register cannot be translated using keytrans() when it involves character search (iddqd505) Solution: Record a K_IGNORE instead of a K_NOP (zeertzjq) related: #13916 closes: #13925 Signed-off-by: zeertzjq <zeertzjq@outlook.com> Signed-off-by: Christian Brabandt <cb@256bit.org>
author Christian Brabandt <cb@256bit.org>
date Sun, 28 Jan 2024 19:15:03 +0100
parents 1629cc65d78d
children 89f9a7925fff
line wrap: on
line diff
--- a/src/normal.c
+++ b/src/normal.c
@@ -568,10 +568,10 @@ normal_cmd_get_more_chars(
 	    ++no_mapping;
 	    // Vim may be in a different mode when the user types the next key,
 	    // but when replaying a recording the next key is already in the
 	    // typeahead buffer, so record a <Nop> before that to prevent the
 	    // vpeekc() above from applying wrong mappings when replaying.
 	    ++no_u_sync;
-	    gotchars_nop();
+	    gotchars_ignore();
 	    --no_u_sync;
 	}
     }
@@ -568,10 +568,10 @@ normal_cmd_get_more_chars(
 	    // Vim may be in a different mode when the user types the next key,
 	    // but when replaying a recording the next key is already in the
-	    // typeahead buffer, so record a <Nop> before that to prevent the
-	    // vpeekc() above from applying wrong mappings when replaying.
+	    // typeahead buffer, so record an <Ignore> before that to prevent
+	    // the vpeekc() above from applying wrong mappings when replaying.
 	    ++no_u_sync;